@@ -4,22 +4,22 @@ from rest_framework.exceptions import APIException
 
 
 __all__ = [
-    "EmailServerException",
-    "LoginCodeStillValid",
+    "ServerException",
     "CorruptedDataException",
+    "SendCodeCooldown",
 ]
 
 
-class EmailServerException(APIException):
+class ServerException(APIException):
     status_code = status.HTTP_503_SERVICE_UNAVAILABLE
-    default_detail = _("Email server did not respond.")
-    default_code = "email_server_down"
+    default_detail = _("Server did not respond.")
+    default_code = "server_down"
 
 
-class LoginCodeStillValid(APIException):
-    status_code = status.HTTP_409_CONFLICT
-    default_detail = _("A login code for this email is still valid.")
-    default_code = "login_still_valid"
+class SendCodeCooldown(APIException):
+    status_code = status.HTTP_412_PRECONDITION_FAILED
+    default_detail = _("This user is not allowed to send another login code yet.")
+    default_code = "send_code_cooldown"
 
 
 class CorruptedDataException(APIException):
